@@ -6,7 +6,7 @@ use warnings;
 
 =head1 NAME
 
-VSGDR::UnitTest::TestSet::Representation::XLS - The great new VSGDR::UnitTest::TestSet::Representation::XLS!
+VSGDR::UnitTest::TestSet::Representation::XLS - Sealed class for Microsoft Visual Studio Database Edition UnitTest Utility Suite by Ded MedVed
 
 =head1 VERSION
 
